@@ -1,5 +1,8 @@
 # this file only keeps the most common & critical types/utility functions
 from .common import PathIsh, Paths, Json
-from .common import get_files, LazyLogger
+from .common import get_files
+from .common import LazyLogger
 from .common import warn_if_empty
+from .common import stat
+
 from .cfg import make_config
