@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 import sys
 from subprocess import check_call, run, PIPE
+from typing import Optional, Sequence
 import importlib
 import traceback
 
@@ -10,6 +11,23 @@ from . import LazyLogger
 log = LazyLogger('HPI cli')
 
 
+import functools
+@functools.lru_cache()
+def mypy_cmd() -> Optional[Sequence[str]]:
+    try:
+        # preferrably, use mypy from current python env
+        import mypy
+        return ['python3', '-m', 'mypy']
+    except ImportError:
+        pass
+    # ok, not ideal but try from PATH
+    import shutil
+    if shutil.which('mypy'):
+        return ['mypy']
+    warning("mypy not found, so can't check config with it. See https://github.com/python/mypy#readme if you want to install it and retry")
+    return None
+
+
 def run_mypy(pkg):
     from .preinit import get_mycfg_dir
     mycfg_dir = get_mycfg_dir()
@@ -22,8 +40,12 @@ def run_mypy(pkg):
     mpath = str(mycfg_dir) + ('' if mpath is None else f':{mpath}')
     env['MYPYPATH'] = mpath
 
+
+    cmd = mypy_cmd()
+    if cmd is None:
+        return None
     mres = run([
-        'python3', '-m', 'mypy',
+        *cmd,
         '--namespace-packages',
         '--color-output', # not sure if works??
         '--pretty',
@@ -99,27 +121,29 @@ def config_check(args):
 
     info(f"config file: {cfg.__file__}")
 
-    try:
-        import mypy
-    except ImportError:
-        warning("mypy not found, can't check config with it")
+    mres = run_mypy(cfg)
+    if mres is None: # no mypy
+        return
+    rc = mres.returncode
+    if rc == 0:
+        info('mypy check: success')
     else:
-        mres = run_mypy(cfg)
-        rc = mres.returncode
-        if rc == 0:
-            info('mypy check: success')
-        else:
-            error('mypy check: failed')
-            sys.stderr.write(indent(mres.stderr.decode('utf8')))
-        sys.stderr.write(indent(mres.stdout.decode('utf8')))
+        error('mypy check: failed')
+        sys.stderr.write(indent(mres.stderr.decode('utf8')))
+    sys.stderr.write(indent(mres.stdout.decode('utf8')))
 
 
 def modules_check(args):
-    verbose = args.verbose
+    verbose: bool         = args.verbose
+    module: Optional[str] = args.module
     vw = '' if verbose else '; pass --verbose to print more information'
 
-    from .util import get_modules
-    for m in get_modules():
+    if module is None:
+        from .util import get_modules
+        modules = get_modules()
+    else:
+        modules = [module]
+    for m in modules:
         try:
             mod = importlib.import_module(m)
         except Exception as e:
@@ -170,6 +194,7 @@ Work in progress, will be used for config management, troubleshooting & introspe
     sp = p.add_subparsers(dest='mode')
     dp = sp.add_parser('doctor', help='Run various checks')
     dp.add_argument('--verbose', action='store_true', help='Print more diagnosic infomration')
+    dp.add_argument('module', nargs='?', type=str   , help='Pass to check a specific module')
     dp.set_defaults(func=doctor)
 
     cp = sp.add_parser('config', help='Work with configuration')
@@ -191,17 +216,16 @@ def main():
     p = parser()
     args = p.parse_args()
 
-    func = args.func
+    func = getattr(args, 'func', None)
     if func is None:
-        # shouldn't happen.. but just in case
-        p.print_usage()
+        p.print_help()
         sys.exit(1)
 
     import tempfile
     with tempfile.TemporaryDirectory() as td:
         # cd into tmp dir to prevent accidental imports..
         os.chdir(str(td))
-        args.func(args)
+        func(args)
 
 
 if __name__ == '__main__':
