@@ -116,9 +116,21 @@ from ..kython.klogging import setup_logger, LazyLogger
 
 Paths = Union[Sequence[PathIsh], PathIsh]
 
+
+def _is_compressed(p: Path) -> bool:
+    # todo kinda lame way for now.. use mime ideally?
+    # should cooperate with kompress.kopen?
+    return p.suffix in {'.xz', '.lz4', '.zstd'}
+
+
 # TODO support '' for emtpy path
 DEFAULT_GLOB = '*'
-def get_files(pp: Paths, glob: str=DEFAULT_GLOB, sort: bool=True) -> Tuple[Path, ...]:
+def get_files(
+        pp: Paths,
+        glob: str=DEFAULT_GLOB,
+        sort: bool=True,
+        guess_compression: bool=True,
+) -> Tuple[Path, ...]:
     """
     Helper function to avoid boilerplate.
 
@@ -146,7 +158,7 @@ def get_files(pp: Paths, glob: str=DEFAULT_GLOB, sort: bool=True) -> Tuple[Path,
         if src.parts[0] == '~':
             src = src.expanduser()
         if src.is_dir():
-            gp: Iterable[Path] = src.glob(glob)
+            gp: Iterable[Path] = src.glob(glob) # todo not sure if should be recursive?
             paths.extend(gp)
         else:
             ss = str(src)
@@ -170,6 +182,9 @@ def get_files(pp: Paths, glob: str=DEFAULT_GLOB, sort: bool=True) -> Tuple[Path,
         warnings.warn(f'{caller()}: no paths were matched against {paths}. This might result in missing data.')
         traceback.print_stack()
 
+    if guess_compression:
+        from ..kython.kompress import CPath # todo move to core?
+        paths = [CPath(p) if _is_compressed(p) else p for p in paths]
     return tuple(paths)
 
 
@@ -350,18 +365,54 @@ C = TypeVar('C')
 def stat(func: Callable[[], Iterable[C]]) -> Dict[str, Any]:
     from more_itertools import ilen, take, first
 
-    it = iter(func())
-    res: Any
+    # todo not sure if there is something in more_itertools to compute this?
+    errors = 0
+    last = None
+    def funcit():
+        nonlocal errors, last
+        for x in func():
+            if isinstance(x, Exception):
+                errors += 1
+            else:
+                last = x
+            yield x
+
+    it = iter(funcit())
+    count: Any
     if QUICK_STATS:
         initial = take(100, it)
-        res = len(initial)
+        count = len(initial)
         if first(it, None) is not None: # todo can actually be none...
             # haven't exhausted
-            res = f'{res}+'
+            count = f'{count}+'
     else:
-        res = ilen(it)
+        count = ilen(it)
 
+    res = {
+        'count': count,
+    }
+
+    if errors > 0:
+        res['errors'] = errors
+
+    if last is not None:
+        dt = guess_datetime(last)
+        if dt is not None:
+            res['last'] = dt
 
     return {
         func.__name__: res,
     }
+
+
+# experimental, not sure about it..
+def guess_datetime(x: Any) -> Optional[datetime]:
+    # todo support datacalsses
+    asdict = getattr(x, '_asdict', None)
+    if asdict is None:
+        return None
+    # todo check if there are multiple?
+    for k, v in asdict().items():
+        if isinstance(v, datetime):
+            return v
+    return None
