@@ -66,13 +66,8 @@ logger = LazyLogger(__name__, level='debug')
 
 
 from pathlib import Path
-from .kython.kompress import CPath
 def inputs() -> Sequence[Path]:
-    files = get_files(config.export_path)
-    # TODO Cpath better be automatic by get_files...
-    res = list(map(CPath, files)); assert len(res) > 0
-    # todo move the assert to get_files?
-    return tuple(res)
+    return get_files(config.export_path)
 
 
 Sid        = dal.Sid
@@ -83,25 +78,27 @@ Upvote     = dal.Upvote
 
 
 def _dal() -> dal.DAL:
-    return dal.DAL(inputs())
+    inp = list(inputs())
+    return dal.DAL(inp)
+cache = mcachew(hashf=inputs) # depends on inputs only
 
 
-@mcachew(hashf=lambda: inputs())
+@cache
 def saved() -> Iterator[Save]:
     return _dal().saved()
 
 
-@mcachew(hashf=lambda: inputs())
+@cache
 def comments() -> Iterator[Comment]:
     return _dal().comments()
 
 
-@mcachew(hashf=lambda: inputs())
+@cache
 def submissions() -> Iterator[Submission]:
     return _dal().submissions()
 
 
-@mcachew(hashf=lambda: inputs())
+@cache
 def upvoted() -> Iterator[Upvote]:
     return _dal().upvoted()
 
@@ -144,8 +141,10 @@ class Event(NamedTuple):
 Url = str
 
 def _get_bdate(bfile: Path) -> datetime:
-    RE = re.compile(r'reddit-(\d{14})')
-    match = RE.search(bfile.stem)
+    RE = re.compile(r'reddit.(\d{14})')
+    stem = bfile.stem
+    stem = stem.replace('T', '').replace('Z', '') # adapt for arctee
+    match = RE.search(stem)
     assert match is not None
     bdt = pytz.utc.localize(datetime.strptime(match.group(1), "%Y%m%d%H%M%S"))
     return bdt
@@ -164,7 +163,7 @@ def _get_state(bfile: Path) -> Dict[Sid, SaveWithDt]:
 
 # TODO hmm. think about it.. if we set default backups=inputs()
 # it's called early so it ends up as a global variable that we can't monkey patch easily
-@mcachew('/L/data/.cache/reddit-events.cache')
+@mcachew
 def _get_events(backups: Sequence[Path], parallel: bool=True) -> Iterator[Event]:
     # TODO cachew: let it transform return type? so you don't have to write a wrapper for lists?
 
@@ -217,22 +216,29 @@ def _get_events(backups: Sequence[Path], parallel: bool=True) -> Iterator[Event]
 
 @lru_cache(1)
 def events(*args, **kwargs) -> List[Event]:
-    evit = _get_events(inputs(), *args, **kwargs)
+    inp = inputs()
+    # 2.2s for 300 files without cachew
+    # 0.2s for 300 files with cachew
+    evit = _get_events(inp, *args, **kwargs)
     return list(sorted(evit, key=lambda e: e.cmp_key))
 
+
+def stats():
+    from .core import stat
+    return {
+        **stat(saved      ),
+        **stat(comments   ),
+        **stat(submissions),
+        **stat(upvoted    ),
+    }
+
+
 ##
 
 
 def main() -> None:
-    # TODO eh. not sure why but parallel on seems to mess glumov up and cause OOM...
-    el = events(parallel=False)
-    print(len(el))
-    for e in el:
-        print(e.text, e.url)
-    # for e in get_
-    # 509 with urls..
-    # for e in get_events():
-    #     print(e)
+    for e in events(parallel=False):
+        print(e)
 
 
 if __name__ == '__main__':
